"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
const _os = /*#__PURE__*/ _interopRequireDefault(require("os"));
const _createModuleIdHOF = require("../createModuleIdHOF");
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
describe('[unix] createModuleIdHOF', ()=>{
    const opts = {
        projectRoot: '/Users/simon/Developer/huya/super-fans-promotion',
        SDKAlias: {
            'open-sdk': [
                '@hyext/ext-sdk-hy'
            ]
        }
    };
    const cases = [
        [
            '/Users/simon/Developer/huya/super-fans-promotion/src/config/env.conf.tsx',
            'super-fans-promotion_src_config_env.conf.tsx'
        ],
        [
            '/Users/simon/Developer/huya/super-fans-promotion/src/config/env.conf.js',
            'super-fans-promotion_src_config_env.conf'
        ],
        [
            '/Users/simon/Developer/huya/super-fans-promotion/node_modules/barfoo/config/env.conf.js',
            'node_modules_barfoo_config_env.conf'
        ],
        [
            '/Users/simon/Developer/huya/super-fans-promotion/node_modules/@hyext/ext-sdk-hy/src/config/env.conf.js',
            'open-sdk_src_config_env.conf'
        ],
        [
            '/Users/simon/Developer/huya/super-fans-promotion/node_modules/react-native/Libraries/barfoo/config/env.conf.js',
            'RN_env.conf'
        ],
        [
            '/Users/simon/Developer/huya/super-fans-promotion/node_modules/react-native/Libraries/barfoo/config/env.conf.tsx',
            'RN_env.conf.tsx'
        ]
    ];
    if (_os.default.platform() !== 'win32') {
        test.each(cases)(`case %#: %s => %s`, (input, expected)=>{
            expect((0, _createModuleIdHOF.getId)(input, opts)).toEqual(expected);
        });
    }
});
describe('[windows] createModuleIdHOF', ()=>{
    const opts = {
        projectRoot: 'D:\\Users\\simon\\Developer\\huya\\super-fans-promotion',
        SDKAlias: {
            'open-sdk': [
                '@hyext/ext-sdk-hy'
            ]
        }
    };
    const cases = [
        [
            'D:\\Users\\simon\\Developer\\huya\\super-fans-promotion\\src\\config\\env.conf.tsx',
            'super-fans-promotion_src_config_env.conf.tsx'
        ],
        [
            'D:\\Users\\simon\\Developer\\huya\\super-fans-promotion\\src\\config\\env.conf.js',
            'super-fans-promotion_src_config_env.conf'
        ],
        [
            'D:\\Users\\simon\\Developer\\huya\\super-fans-promotion\\node_modules\\barfoo\\config\\env.conf.js',
            'node_modules_barfoo_config_env.conf'
        ],
        [
            'D:\\Users\\simon\\Developer\\huya\\super-fans-promotion\\node_modules\\@hyext\\ext-sdk-hy\\src\\config\\env.conf.js',
            'open-sdk_src_config_env.conf'
        ],
        [
            'D:\\Users\\simon\\Developer\\huya\\super-fans-promotion\\node_modules\\react-native\\Libraries\\barfoo\\config\\env.conf.js',
            'RN_env.conf'
        ],
        [
            'D:\\Users\\simon\\Developer\\huya\\super-fans-promotion\\node_modules\\react-native\\Libraries\\barfoo\\config\\env.conf.tsx',
            'RN_env.conf.tsx'
        ]
    ];
    if (_os.default.platform() === 'win32') {
        test.each(cases)(`case %#: %s => %s`, (input, expected)=>{
            expect((0, _createModuleIdHOF.getId)(input, opts)).toEqual(expected);
        });
    }
});
