"use strict";
const cssLoader = require('@hyext/compile');
const upstreamTransformer = require('metro-react-native-babel-transformer');
const { extname  } = require('path');
const BabelJsx2StyleheetPlugin = require('babel-plugin-transform-jsx-to-hy-stylesheet');
const BabelJsxSyntaxPlugin = require('@babel/plugin-syntax-jsx');
const BabelProposalClassPlugin = require('@babel/plugin-proposal-class-properties');
const BabelTypescriptPlugin = require('@babel/plugin-transform-typescript');
// type transformerArgs = {
//   filename: string;
//   options: {
//     hyextTransformerConfig?: {
//      scalePx2dp_design_width?: number,
//      scalePx2dp_disable?: boolean,
//      scalePx2dp_by_orientation_width?: boolean,
//     }
//   };
//   plugins: [string, object][];
//   src: string;
// };
const babelPluginsStr = process.env.MATRIX_BABEL_PLUGINS || '[]';
const hyextTransformerConfigStr = process.env.MATRIX_HYEXT_TRANSFORMER_CONFIG || '{}';
module.exports = {
    transform: function(args, registryPath, assetPlugins) {
        let { src , filename , options , plugins =[]  } = args;
        const finalOptions = {
            ...options,
            hyextTransformerConfig: JSON.parse(hyextTransformerConfigStr)
        };
        let finalPlugins = [
            ...plugins,
            ...JSON.parse(babelPluginsStr)
        ];
        // 不管是业务文件还是 npm 文件 , 都进行 css/hycss 的预处理
        if (filename.endsWith(".css") || filename.endsWith(".hycss")) {
            src = cssLoader.feature.transformCss2Js(src, filename, finalOptions, finalPlugins);
        }
        // 处理业务的js文件, 进行stylesheet 的预处理
        const codeExts = [
            '.js',
            '.jsx',
            '.tsx',
            '.ts'
        ];
        if (!filename.includes('node_modules') && codeExts.includes(extname(filename))) {
            // 如果分两次 transform 的话, sourcemap 信息会丢失
            // src = cssLoader.feature.transformStylesheet(src, filename, finalOptions, finalPlugins);
            finalPlugins = [
                ...finalPlugins,
                [
                    BabelJsx2StyleheetPlugin,
                    {
                        replacePath: false
                    }
                ],
                [
                    BabelJsxSyntaxPlugin
                ],
                [
                    BabelProposalClassPlugin
                ],
                [
                    BabelTypescriptPlugin,
                    {
                        isTSX: true
                    }
                ]
            ];
        }
        return upstreamTransformer.transform({
            src,
            filename,
            options: finalOptions,
            plugins: finalPlugins
        });
    }
};
