"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const createModuleIdHOF_1 = require("./createModuleIdHOF");
const skipModulePaths = new Set();
function filterModuleHOF(options) {
    if (options.mode !== 'production') {
        // 开发模式下打包所有
        return () => true;
    }
    const { projectRoot, filterModules, SDKAlias = {} } = options;
    const moduleIdFactory = (0, createModuleIdHOF_1.createModuleIdHOF)({ projectRoot, SDKAlias, filterModules })();
    return function processModuleFilter(module) {
        const modulePath = module['path'];
        if (skipModulePaths.has(modulePath)) {
            return false;
        }
        {
            // 模块系统是副作用, 只能在 baseModule 中建立
            // 如果业务包又重新执行的话, 会导致基础包中定义的模块被重置而无法被找到
            // 一般来说, filterModules 会包含. 但是如果构建sdk用的metro版本和构建业务的版本不一样
            // 可能会引起id的变化, 所以这里进行额外的校验
            // filterModules 里的ID: node_modules_metro-runtime_src_polyfills_require // 0.67
            // node_modules_metro_src_lib_polyfills_require // 0.62
            const metroModuleSystem = [
                '/node_modules/metro-runtime/src/polyfills/require.js',
                '/node_modules/metro/src/lib/polyfills/require.js', // 0.62
            ];
            if (metroModuleSystem.some(xs => modulePath.endsWith(xs))) {
                skipModulePaths.add(modulePath);
                return false;
            }
        }
        const moduleId = moduleIdFactory(modulePath);
        if (filterModules.has(moduleId)) {
            skipModulePaths.add(modulePath);
            return false;
        }
        return true;
    };
}
exports.default = filterModuleHOF;
module.exports = filterModuleHOF;
